@@ -192,7 +192,7 @@ seed_union_get_property (JSContextRef context,
   cproperty_name = g_alloca (length * sizeof (gchar));
   JSStringGetUTF8CString (property_name, cproperty_name, length);
 
-  SEED_NOTE (STRUCTS, "Getting property on union of type: %s  "
+  SEED_NOTE (STRUCTS, "Getting property on union of type: %s "
 	     "with name %s \n",
 	     g_base_info_get_name (priv->info), cproperty_name);
 
@@ -508,7 +508,7 @@ seed_union_prototype (JSContextRef ctx, GIBaseInfo * info)
   key = g_strjoin (NULL, namespace, name, NULL);
 
   proto = (JSObjectRef) g_hash_table_lookup (union_prototype_hash, key);
-
+  
   if (!proto)
     {
       proto = JSObjectMake (ctx, 0, 0);
@@ -690,7 +690,12 @@ seed_construct_struct_type_with_parameters (JSContextRef ctx,
     {
       size = g_union_info_get_size ((GIUnionInfo *) info);
     }
-  g_assert (size);
+  if (!size)
+    {
+      g_critical ("Struct/union of type: %s has size 0 in introspection data. Please check GIR",
+		  g_base_info_get_name (info));
+      g_assert(size);
+    }
   object = g_slice_alloc0 (size);
 
   SEED_NOTE (CONSTRUCTION,
